@@ -19,8 +19,8 @@
  */
 
 
-#ifndef _LIB_DMMP_H_
-#define _LIB_DMMP_H_
+#ifndef LIBDMMP_H_INCLUDED
+#define LIBDMMP_H_INCLUDED
 
 #include <stdint.h>
 #include <stdarg.h>
@@ -42,6 +42,7 @@ extern "C" {
 #define DMMP_ERR_MPATH_BUSY		7
 #define DMMP_ERR_MPATH_NOT_FOUND	8
 #define DMMP_ERR_INVALID_ARGUMENT	9
+#define DMMP_ERR_PERMISSION_DENY	10
 
 /*
  * Use the syslog severity level as log priority
@@ -258,7 +259,8 @@ DMMP_DLL_EXPORT int dmmp_context_log_priority_get(struct dmmp_context *ctx);
  *	Pointer of 'struct dmmp_context'.
  *	If this pointer is NULL, your program will be terminated by assert.
  * @log_func:
- *	Pointer of log handler function.
+ *	Pointer of log handler function. If set to NULL, all log will be
+ *	ignored.
  *
  * Return:
  *	void
@@ -387,7 +389,7 @@ DMMP_DLL_EXPORT const char *dmmp_mpath_name_get(struct dmmp_mpath *dmmp_mp);
  * dmmp_mpath_kdev_name_get() - Retrieve kernel DEVNAME of certain mpath.
  *
  * Retrieve DEVNAME name used by kernel uevent of specified mpath.
- * Example: 'dm-1'.
+ * For example: 'dm-1'.
  *
  * @dmmp_mp:
  *	Pointer of 'struct dmmp_mpath'.
@@ -551,8 +553,8 @@ DMMP_DLL_EXPORT void dmmp_path_array_get(struct dmmp_path_group *dmmp_pg,
 /**
  * dmmp_path_blk_name_get() - Retrieve block name.
  *
- * Retrieve block name of certain path. The example of block names are 'sda',
- * 'nvme0n1'.
+ * Retrieve block name of certain path. The example of block names are "sda",
+ * "nvme0n1".
  *
  * @dmmp_p:
  *	Pointer of 'struct dmmp_path'.
@@ -678,6 +680,8 @@ DMMP_DLL_EXPORT const char *dmmp_path_status_str(uint32_t path_status);
  *
  *	* DMMP_ERR_INVALID_ARGUMENT
  *
+ *	* DMMP_ERR_PERMISSION_DENY
+ *
  *	Error number could be converted to string by dmmp_strerror().
  */
 DMMP_DLL_EXPORT int dmmp_flush_mpath(struct dmmp_context *ctx,
@@ -703,12 +707,29 @@ DMMP_DLL_EXPORT int dmmp_flush_mpath(struct dmmp_context *ctx,
  *
  *	* DMMP_ERR_NO_DAEMON
  *
+ *	* DMMP_ERR_PERMISSION_DENY
+ *
  *	Error number could be converted to string by dmmp_strerror().
  */
 DMMP_DLL_EXPORT int dmmp_reconfig(struct dmmp_context *ctx);
 
+/**
+ * dmmp_last_error_msg() - Retrieves the last error message.
+ *
+ * Retrieves the last error message.
+ *
+ * @ctx:
+ *	Pointer of 'struct dmmp_context'.
+ *	If this pointer is NULL, your program will be terminated by assert.
+ *
+ * Return:
+ *	const char *. No need to free this memory, the resources will get
+ *	freed when dmmp_context_free().
+ */
+DMMP_DLL_EXPORT const char *dmmp_last_error_msg(struct dmmp_context *ctx);
+
 #ifdef __cplusplus
 } /* End of extern "C" */
 #endif
 
-#endif /* End of _LIB_DMMP_H_ */
+#endif /* End of LIBDMMP_H_INCLUDED */
