@@ -94,9 +94,10 @@ static size_t write_all(int fd, const void *buf, size_t len)
 /*
  * connect to a unix domain socket
  */
-int __mpath_connect(int nonblocking)
+int mpath_connect__(int nonblocking)
 {
-	int fd, len;
+	int fd;
+	size_t len;
 	struct sockaddr_un addr;
 	int flags = 0;
 
@@ -132,12 +133,15 @@ int __mpath_connect(int nonblocking)
 	return fd;
 }
 
+extern int __mpath_connect(int)
+	__attribute__((weak, alias("mpath_connect__")));
+
 /*
  * connect to a unix domain socket
  */
 int mpath_connect(void)
 {
-	return __mpath_connect(0);
+	return mpath_connect__(0);
 }
 
 int mpath_disconnect(int fd)
@@ -169,10 +173,12 @@ int mpath_recv_reply_data(int fd, char *reply, size_t len,
 {
 	ssize_t ret;
 
+	if (len <= 0)
+		return 0;
 	ret = read_all(fd, reply, len, timeout);
 	if (ret < 0)
 		return ret;
-	if (ret != len) {
+	if ((size_t)ret != len) {
 		errno = EIO;
 		return -1;
 	}
