@@ -70,7 +70,7 @@ struct binding {
  * Perhaps one day we'll implement this more efficiently, thus use
  * an abstract type.
  */
-typedef struct _vector Bindings;
+typedef struct vector_s Bindings;
 
 /* Protect global_bindings */
 static pthread_mutex_t bindings_mutex = PTHREAD_MUTEX_INITIALIZER;
@@ -162,7 +162,7 @@ static const struct binding *get_binding_for_wwid(const Bindings *bindings,
  * This is achieved by sorting be length first, then using strcmp().
  * If multiple prefixes are in use, the aliases with a given prefix will
  * not necessarily be in a contiguous range of the vector, but they will
- * be ordered such that for a given prefix, numercally higher aliases will
+ * be ordered such that for a given prefix, numerically higher aliases will
  * always be sorted after lower ones.
  */
 static int alias_compar(const void *p1, const void *p2)
@@ -242,7 +242,7 @@ static int write_bindings_file(const Bindings *bindings, int fd,
 	int i;
 	size_t len;
 
-	if (__append_strbuf_str(&content, BINDINGS_FILE_HEADER,
+	if (append_strbuf_str__(&content, BINDINGS_FILE_HEADER,
 				sizeof(BINDINGS_FILE_HEADER) - 1) == -1)
 		return -1;
 
@@ -408,13 +408,18 @@ static bool alias_already_taken(const char *alias, const char *map_wwid)
 {
 
 	char wwid[WWID_SIZE];
+	int rc = dm_get_wwid(alias, wwid, sizeof(wwid));
 
-	/* If the map doesn't exist, it's fine */
-	if (dm_get_uuid(alias, wwid, sizeof(wwid)) != 0)
+	/*
+	 * If the map doesn't exist, it's fine.
+	 * In the generic error case, assume that the device is not
+	 * taken, and try to proceed.
+	 */
+	if (rc == DMP_NOT_FOUND || rc == DMP_ERR)
 		return false;
 
 	/* If both the name and the wwid match, it's fine.*/
-	if (strncmp(map_wwid, wwid, sizeof(wwid)) == 0)
+	if (rc == DMP_OK && strncmp(map_wwid, wwid, sizeof(wwid)) == 0)
 		return false;
 
 	condlog(3, "%s: alias '%s' already taken, reselecting alias",
@@ -560,7 +565,7 @@ static void read_bindings_file(void)
  *    bindings file fails.
  *  - if "alias_old" is set, it can't be bound to a different map. alias_old is
  *    initialized in find_existing_alias() by scanning the mpvec. We trust
- *    that the mpvec corrcectly represents kernel state.
+ *    that the mpvec correctly represents kernel state.
  */
 
 char *get_user_friendly_alias(const char *wwid, const char *alias_old,
