@@ -1,7 +1,8 @@
-#ifndef _CHECKERS_H
-#define _CHECKERS_H
+#ifndef CHECKERS_H_INCLUDED
+#define CHECKERS_H_INCLUDED
 
 #include <pthread.h>
+#include <stdbool.h>
 #include "list.h"
 #include "defaults.h"
 
@@ -123,6 +124,7 @@ struct checker {
 	int fd;
 	unsigned int timeout;
 	int disable;
+	int path_state;
 	short msgid;		             /* checker-internal extra status */
 	void * context;                      /* store for persistent data */
 	void ** mpcontext;                   /* store for persistent data shared
@@ -169,7 +171,9 @@ struct checker_context {
 };
 int start_checker_thread (pthread_t *thread, const pthread_attr_t *attr,
 			  struct checker_context *ctx);
-int checker_check (struct checker *, int);
+int checker_get_state(struct checker *c);
+bool checker_need_wait(struct checker *c);
+void checker_check (struct checker *, int);
 int checker_is_sync(const struct checker *);
 const char *checker_name (const struct checker *);
 void reset_checker_classes(void);
@@ -186,6 +190,10 @@ int libcheck_check(struct checker *);
 int libcheck_init(struct checker *);
 void libcheck_free(struct checker *);
 void *libcheck_thread(struct checker_context *ctx);
+void libcheck_reset(void);
+int libcheck_mp_init(struct checker *);
+int libcheck_pending(struct checker *c);
+bool libcheck_need_wait(struct checker *c);
 
 /*
  * msgid => message map.
@@ -194,9 +202,9 @@ void *libcheck_thread(struct checker_context *ctx);
  * message IDs.
  * Message IDs available to checkers start at CHECKER_FIRST_MSG.
  * The msgtable array is 0-based, i.e. msgtable[0] is the message
- * for msgid == __CHECKER_FIRST_MSG.
+ * for msgid == CHECKER_FIRST_MSG.
  * The table ends with a NULL element.
  */
 extern const char *libcheck_msgtable[];
 
-#endif /* _CHECKERS_H */
+#endif /* CHECKERS_H_INCLUDED */
