@@ -1,5 +1,5 @@
-#ifndef _CONFIG_H
-#define _CONFIG_H
+#ifndef CONFIG_H_INCLUDED
+#define CONFIG_H_INCLUDED
 
 #include <sys/types.h>
 #include <stdint.h>
@@ -76,6 +76,8 @@ struct hwentry {
 	int retain_hwhandler;
 	int detect_prio;
 	int detect_checker;
+	int detect_pgpolicy;
+	int detect_pgpolicy_use_tpg;
 	int deferred_remove;
 	int delay_watch_checks;
 	int delay_wait_checks;
@@ -145,7 +147,7 @@ struct config {
 	int minio_rq;
 	unsigned int checkint;
 	unsigned int max_checkint;
-	bool use_watchdog;
+	unsigned int adjust_int;
 	int pgfailback;
 	int rr_weight;
 	int no_path_retry;
@@ -160,6 +162,7 @@ struct config {
 	int fast_io_fail;
 	unsigned int dev_loss;
 	int eh_deadline;
+	int max_retries;
 	int log_checker_err;
 	int allow_queueing;
 	int allow_usb_devices;
@@ -171,6 +174,8 @@ struct config {
 	int retain_hwhandler;
 	int detect_prio;
 	int detect_checker;
+	int detect_pgpolicy;
+	int detect_pgpolicy_use_tpg;
 	int force_sync;
 	int deferred_remove;
 	int processed_main_config;
@@ -197,15 +202,13 @@ struct config {
 	int skip_delegate;
 	unsigned int sequence_nr;
 	int recheck_wwid;
+	int auto_resize;
 
 	char * selector;
-	struct _vector uid_attrs;
+	struct vector_s uid_attrs;
 	char * uid_attribute;
 	char * features;
 	char * hwhandler;
-	char * bindings_file;
-	char * wwids_file;
-	char * prkeys_file;
 	char * prio_name;
 	char * prio_args;
 	char * checker_name;
@@ -282,11 +285,11 @@ int libmultipath_init(void);
  */
 void libmultipath_exit(void);
 
-int find_hwe (const struct _vector *hwtable,
+int find_hwe (const struct vector_s *hwtable,
 	      const char * vendor, const char * product, const char *revision,
 	      vector result);
 struct mpentry * find_mpe (vector mptable, char * wwid);
-const char *get_mpe_wwid (const struct _vector *mptable, const char *alias);
+const char *get_mpe_wwid (const struct vector_s *mptable, const char *alias);
 
 struct hwentry * alloc_hwe (void);
 struct mpentry * alloc_mpe (void);
