@@ -1,5 +1,5 @@
-#ifndef DISCOVERY_H
-#define DISCOVERY_H
+#ifndef DISCOVERY_H_INCLUDED
+#define DISCOVERY_H_INCLUDED
 
 #define SYSFS_PATH_SIZE 255
 #define INQUIRY_CMDLEN  6
@@ -33,8 +33,10 @@ struct config;
 int path_discovery (vector pathvec, int flag);
 int path_get_tpgs(struct path *pp); /* This function never returns TPGS_UNDEF */
 int do_tur (char *);
-int path_offline (struct path *);
-int get_state (struct path * pp, struct config * conf, int daemon, int state);
+int path_sysfs_state(struct path *);
+int start_checker(struct path * pp, struct config * conf, int daemon,
+		  int state);
+int get_state(struct path * pp);
 int get_vpd_sgio (int fd, int pg, int vend_id, char * str, int maxlen);
 int pathinfo (struct path * pp, struct config * conf, int mask);
 int alloc_path_with_pathinfo (struct config *conf, struct udev_device *udevice,
@@ -62,26 +64,26 @@ bool is_vpd_page_supported(int fd, int pg);
  * discovery bitmask
  */
 enum discovery_mode {
-	__DI_SYSFS,
-	__DI_SERIAL,
-	__DI_CHECKER,
-	__DI_PRIO,
-	__DI_WWID,
-	__DI_BLACKLIST,
-	__DI_NOIO,
-	__DI_NOFALLBACK,
+	DI_SYSFS__,
+	DI_SERIAL__,
+	DI_CHECKER__,
+	DI_PRIO__,
+	DI_WWID__,
+	DI_BLACKLIST__,
+	DI_NOIO__,
+	DI_NOFALLBACK__,
 };
 
-#define DI_SYSFS	(1 << __DI_SYSFS)
-#define DI_SERIAL	(1 << __DI_SERIAL)
-#define DI_CHECKER	(1 << __DI_CHECKER)
-#define DI_PRIO		(1 << __DI_PRIO)
-#define DI_WWID		(1 << __DI_WWID)
-#define DI_BLACKLIST	(1 << __DI_BLACKLIST)
-#define DI_NOIO		(1 << __DI_NOIO) /* Avoid IO on the device */
-#define DI_NOFALLBACK	(1 << __DI_NOFALLBACK) /* do not allow wwid fallback */
+#define DI_SYSFS	(1 << DI_SYSFS__)
+#define DI_SERIAL	(1 << DI_SERIAL__)
+#define DI_CHECKER	(1 << DI_CHECKER__)
+#define DI_PRIO		(1 << DI_PRIO__)
+#define DI_WWID		(1 << DI_WWID__)
+#define DI_BLACKLIST	(1 << DI_BLACKLIST__)
+#define DI_NOIO		(1 << DI_NOIO__) /* Avoid IO on the device */
+#define DI_NOFALLBACK	(1 << DI_NOFALLBACK__) /* do not allow wwid fallback */
 
 #define DI_ALL		(DI_SYSFS  | DI_SERIAL | DI_CHECKER | DI_PRIO | \
 			 DI_WWID)
 
-#endif /* DISCOVERY_H */
+#endif /* DISCOVERY_H_INCLUDED */
