@@ -45,7 +45,7 @@ const char *THIS;
 struct nvme_map;
 struct nvme_pathgroup {
 	struct gen_pathgroup gen;
-	struct _vector pathvec;
+	struct vector_s pathvec;
 };
 
 struct nvme_path {
@@ -66,7 +66,7 @@ struct nvme_map {
 	struct udev_device *udev;
 	struct udev_device *subsys;
 	dev_t devt;
-	struct _vector pgvec;
+	struct vector_s pgvec;
 	int nr_live;
 	int ana_supported;
 };
@@ -114,7 +114,7 @@ static void cleanup_nvme_map(struct nvme_map *map)
 	free(map);
 }
 
-static const struct _vector*
+static const struct vector_s*
 nvme_mp_get_pgs(const struct gen_multipath *gmp) {
 	const struct nvme_map *nvme = const_gen_mp_to_nvme(gmp);
 
@@ -124,7 +124,7 @@ nvme_mp_get_pgs(const struct gen_multipath *gmp) {
 
 static void
 nvme_mp_rel_pgs(__attribute__((unused)) const struct gen_multipath *gmp,
-		__attribute__((unused)) const struct _vector *v)
+		__attribute__((unused)) const struct vector_s *v)
 {
 	/* empty */
 }
@@ -201,7 +201,7 @@ static int snprint_nvme_map(const struct gen_multipath *gmp,
 	return append_strbuf_str(buff, N_A);
 }
 
-static const struct _vector*
+static const struct vector_s*
 nvme_pg_get_paths(const struct gen_pathgroup *gpg) {
 	const struct nvme_pathgroup *gp = const_gen_pg_to_nvme(gpg);
 
@@ -211,7 +211,7 @@ nvme_pg_get_paths(const struct gen_pathgroup *gpg) {
 
 static void
 nvme_pg_rel_paths(__attribute__((unused)) const struct gen_pathgroup *gpg,
-		  __attribute__((unused)) const struct _vector *v)
+		  __attribute__((unused)) const struct vector_s *v)
 {
 	/* empty */
 }
@@ -675,7 +675,8 @@ static void _find_controllers(struct context *ctx, struct nvme_map *map)
 	pthread_cleanup_push_cast(free_scandir_result, &sr);
 	for (i = 0; i < r; i++) {
 		char *fn = di[i]->d_name;
-		struct udev_device *ctrl, *udev;
+		struct udev_device *ctrl;
+		struct udev_device *udev __attribute__((cleanup(cleanup_udev_device))) = NULL;
 
 		if (safe_snprintf(pathbuf + n, sizeof(pathbuf) - n, "/%s", fn))
 			continue;
@@ -719,11 +720,11 @@ static void _find_controllers(struct context *ctx, struct nvme_map *map)
 			continue;
 
 		path->gen.ops = &nvme_path_ops;
-		path->udev = udev;
+		path->udev = steal_ptr(udev);
 		path->seen = true;
 		path->map = map;
 		path->ctl = udev_device_get_parent_with_subsystem_devtype
-			(udev, "nvme", NULL);
+			(path->udev, "nvme", NULL);
 		if (path->ctl == NULL) {
 			condlog(1, "%s: %s: failed to get controller for %s",
 				__func__, THIS, fn);
@@ -744,7 +745,7 @@ static void _find_controllers(struct context *ctx, struct nvme_map *map)
 		}
 		vector_set_slot(&map->pgvec, &path->pg);
 		condlog(3, "%s: %s: new path %s added to %s",
-			__func__, THIS, udev_device_get_sysname(udev),
+			__func__, THIS, udev_device_get_sysname(path->udev),
 			udev_device_get_sysname(map->udev));
 	}
 	pthread_cleanup_pop(1);
@@ -891,7 +892,7 @@ int delete(struct context *ctx, struct udev_device *ud)
 	return rc;
 }
 
-void _check(struct context *ctx)
+void check__(struct context *ctx)
 {
 	struct gen_multipath *gm;
 	int i;
@@ -908,7 +909,7 @@ void check(struct context *ctx)
 	condlog(4, "%s called for \"%s\"", __func__, THIS);
 	lock(ctx);
 	pthread_cleanup_push(unlock, ctx);
-	_check(ctx);
+	check__(ctx);
 	pthread_cleanup_pop(1);
 	return;
 }
@@ -916,14 +917,14 @@ void check(struct context *ctx)
 /*
  * It's safe to pass our internal pointer, this is only used under the lock.
  */
-const struct _vector *get_multipaths(const struct context *ctx)
+const struct vector_s *get_multipaths(const struct context *ctx)
 {
 	condlog(5, "%s called for \"%s\"", __func__, THIS);
 	return ctx->mpvec;
 }
 
 void release_multipaths(__attribute__((unused)) const struct context *ctx,
-			__attribute__((unused)) const struct _vector *mpvec)
+			__attribute__((unused)) const struct vector_s *mpvec)
 {
 	condlog(5, "%s called for \"%s\"", __func__, THIS);
 	/* NOP */
@@ -932,7 +933,7 @@ void release_multipaths(__attribute__((unused)) const struct context *ctx,
 /*
  * It's safe to pass our internal pointer, this is only used under the lock.
  */
-const struct _vector * get_paths(const struct context *ctx)
+const struct vector_s * get_paths(const struct context *ctx)
 {
 	vector paths = NULL;
 	const struct gen_multipath *gm;
@@ -948,25 +949,25 @@ const struct _vector * get_paths(const struct context *ctx)
 }
 
 void release_paths(__attribute__((unused)) const struct context *ctx,
-		   const struct _vector *mpvec)
+		   const struct vector_s *mpvec)
 {
 	condlog(5, "%s called for \"%s\"", __func__, THIS);
 	vector_free_const(mpvec);
 }
 
 /* compile-time check whether all methods are present and correctly typed */
-#define _METHOD_INIT(x) .x = x
+#define METHOD_INIT(x) .x = x
 static struct foreign __methods __attribute__((unused)) = {
-	_METHOD_INIT(init),
-	_METHOD_INIT(cleanup),
-	_METHOD_INIT(change),
-	_METHOD_INIT(delete),
-	_METHOD_INIT(delete_all),
-	_METHOD_INIT(check),
-	_METHOD_INIT(lock),
-	_METHOD_INIT(unlock),
-	_METHOD_INIT(get_multipaths),
-	_METHOD_INIT(release_multipaths),
-	_METHOD_INIT(get_paths),
-	_METHOD_INIT(release_paths),
+	METHOD_INIT(init),
+	METHOD_INIT(cleanup),
+	METHOD_INIT(change),
+	METHOD_INIT(delete),
+	METHOD_INIT(delete_all),
+	METHOD_INIT(check),
+	METHOD_INIT(lock),
+	METHOD_INIT(unlock),
+	METHOD_INIT(get_multipaths),
+	METHOD_INIT(release_multipaths),
+	METHOD_INIT(get_paths),
+	METHOD_INIT(release_paths),
 };
