@@ -5,7 +5,7 @@ void cleanup_lock (void * data)
 	struct mutex_lock *lock = data;
 	wakeup_fn *fn = lock->wakeup;
 
-	__unlock(lock);
+	unlock__(lock);
 	if (fn)
 		fn();
 }
@@ -14,5 +14,5 @@ void set_wakeup_fn(struct mutex_lock *lck, wakeup_fn *fn)
 {
 	lock(lck);
 	lck->wakeup = fn;
-	__unlock(lck);
+	unlock__(lck);
 }
