@@ -12,8 +12,8 @@
  * more details.
  */
 
-#ifndef _LINUX_NVME_H
-#define _LINUX_NVME_H
+#ifndef LINUX_NVME_H_INCLUDED
+#define LINUX_NVME_H_INCLUDED
 
 #include <linux/types.h>
 #include <linux/uuid.h>
@@ -1035,7 +1035,7 @@ enum {
 	NVME_SANITIZE_LOG_STATUS_MASK		= 0x0007,
 	NVME_SANITIZE_LOG_NEVER_SANITIZED	= 0x0000,
 	NVME_SANITIZE_LOG_COMPLETED_SUCCESS	= 0x0001,
-	NVME_SANITIZE_LOG_IN_PROGESS		= 0x0002,
+	NVME_SANITIZE_LOG_IN_PROGRESS		= 0x0002,
 	NVME_SANITIZE_LOG_COMPLETED_FAILED	= 0x0003,
 	NVME_SANITIZE_LOG_ND_COMPLETED_SUCCESS	= 0x0004,
 };
@@ -1525,4 +1525,4 @@ struct nvme_completion {
 #define NVME_MINOR(ver)		(((ver) >> 8) & 0xff)
 #define NVME_TERTIARY(ver)	((ver) & 0xff)
 
-#endif /* _LINUX_NVME_H */
+#endif /* LINUX_NVME_H_INCLUDED */
