@@ -1,5 +1,5 @@
-#ifndef _PRKEY_H
-#define _PRKEY_H
+#ifndef PRKEY_H_INCLUDED
+#define PRKEY_H_INCLUDED
 
 #include "structs.h"
 #include <inttypes.h>
@@ -16,9 +16,8 @@
 int print_reservation_key(struct strbuf *buff,
 			  struct be64 key, uint8_t flags, int source);
 int parse_prkey_flags(const char *ptr, uint64_t *prkey, uint8_t *flags);
-int set_prkey(struct config *conf, struct multipath *mpp, uint64_t prkey,
-	      uint8_t sa_flags);
-int get_prkey(struct config *conf, struct multipath *mpp, uint64_t *prkey,
-	      uint8_t *sa_flags);
+int set_prkey(struct config *conf, struct multipath *mpp,
+	      uint64_t prkey, uint8_t sa_flags);
+int get_prkey(struct multipath *mpp, uint64_t *prkey, uint8_t *sa_flags);
 
-#endif /* _PRKEY_H */
+#endif /* PRKEY_H_INCLUDED */
