@@ -48,7 +48,7 @@ do {									\
 	}								\
 } while(0)
 
-#define __do_set_from_vec(type, var, src, dest)				\
+#define do_set_from_vec__(type, var, src, dest)				\
 ({									\
 	type *_p;							\
 	bool _found = false;						\
@@ -64,11 +64,11 @@ do {									\
 	_found;								\
 })
 
-#define __do_set_from_hwe(var, src, dest) \
-	__do_set_from_vec(struct hwentry, var, (src)->hwe, dest)
+#define do_set_from_hwe__(var, src, dest) \
+	do_set_from_vec__(struct hwentry, var, (src)->hwe, dest)
 
 #define do_set_from_hwe(var, src, dest, msg)				\
-	if (src->hwe && __do_set_from_hwe(var, src, dest)) {		\
+	if (src->hwe && do_set_from_hwe__(var, src, dest)) {		\
 		origin = msg;						\
 		goto out;						\
 	}
@@ -255,14 +255,18 @@ verify_alua_prio(struct multipath *mp)
 {
 	int i;
 	struct path *pp;
+	bool assume_alua = false;
 
 	vector_foreach_slot(mp->paths, pp, i) {
 		const char *name = prio_name(&pp->prio);
+		if (!prio_selected(&pp->prio))
+			continue;
 		if (strncmp(name, PRIO_ALUA, PRIO_NAME_LEN) &&
 		    strncmp(name, PRIO_SYSFS, PRIO_NAME_LEN))
 			 return false;
+		assume_alua = true;
 	}
-	return true;
+	return assume_alua;
 }
 
 int select_detect_pgpolicy(struct config *conf, struct multipath *mp)
@@ -660,7 +664,7 @@ check_rdac(struct path * pp)
 	if (pp->bus != SYSFS_BUS_SCSI)
 		return 0;
 	/* Avoid checking 0xc9 if this is likely not an RDAC array */
-	if (!__do_set_from_hwe(checker_name, pp, checker_name) &&
+	if (!do_set_from_hwe__(checker_name, pp, checker_name) &&
 	    !is_vpd_page_supported(pp->fd, 0xC9))
 		return 0;
 	if (checker_name && strcmp(checker_name, RDAC))
@@ -700,6 +704,7 @@ out:
 	condlog(3, "%s: path_checker = %s %s", pp->dev,
 		checker_name(c), origin);
 	c->timeout = pp->checker_timeout;
+	c->path_state = PATH_UNCHECKED;
 	return 0;
 }
 
