@@ -146,8 +146,10 @@ uninitialize_path(struct path *pp)
 		return;
 
 	pp->dmstate = PSTATE_UNDEF;
+	pp->state = PATH_UNCHECKED;
 	pp->uid_attribute = NULL;
 	pp->checker_timeout = 0;
+	pp->pending_ticks = 0;
 
 	if (checker_selected(&pp->checker))
 		checker_put(&pp->checker);
@@ -237,8 +239,18 @@ free_pgvec (vector pgvec, enum free_path_mode free_paths)
 	if (!pgvec)
 		return;
 
-	vector_foreach_slot(pgvec, pgp, i)
+	vector_foreach_slot(pgvec, pgp, i) {
+
+		/* paths are going to be re-grouped, reset pgindex */
+		if (free_paths != FREE_PATHS) {
+			struct path *pp;
+			int j;
+
+			vector_foreach_slot(pgp->paths, pp, j)
+				pp->pgindex = 0;
+		}
 		free_pathgroup(pgp, free_paths);
+	}
 
 	vector_free(pgvec);
 }
@@ -329,6 +341,18 @@ free_multipath (struct multipath * mpp, enum free_path_mode free_paths)
 	free(mpp);
 }
 
+void cleanup_multipath(struct multipath **pmpp)
+{
+	if (*pmpp)
+		free_multipath(*pmpp, KEEP_PATHS);
+}
+
+void cleanup_multipath_and_paths(struct multipath **pmpp)
+{
+	if (*pmpp)
+		free_multipath(*pmpp, FREE_PATHS);
+}
+
 void
 drop_multipath (vector mpvec, char * wwid, enum free_path_mode free_paths)
 {
@@ -419,7 +443,7 @@ store_adaptergroup(vector adapters, struct adapter_group * agp)
 }
 
 struct multipath *
-find_mp_by_minor (const struct _vector *mpvec, unsigned int minor)
+find_mp_by_minor (const struct vector_s *mpvec, unsigned int minor)
 {
 	int i;
 	struct multipath * mpp;
@@ -438,7 +462,7 @@ find_mp_by_minor (const struct _vector *mpvec, unsigned int minor)
 }
 
 struct multipath *
-find_mp_by_wwid (const struct _vector *mpvec, const char * wwid)
+find_mp_by_wwid (const struct vector_s *mpvec, const char * wwid)
 {
 	int i;
 	struct multipath * mpp;
@@ -454,7 +478,7 @@ find_mp_by_wwid (const struct _vector *mpvec, const char * wwid)
 }
 
 struct multipath *
-find_mp_by_alias (const struct _vector *mpvec, const char * alias)
+find_mp_by_alias (const struct vector_s *mpvec, const char * alias)
 {
 	int i;
 	size_t len;
@@ -477,7 +501,7 @@ find_mp_by_alias (const struct _vector *mpvec, const char * alias)
 }
 
 struct multipath *
-find_mp_by_str (const struct _vector *mpvec, const char * str)
+find_mp_by_str (const struct vector_s *mpvec, const char * str)
 {
 	int minor;
 	char dummy;
@@ -496,7 +520,7 @@ find_mp_by_str (const struct _vector *mpvec, const char * str)
 }
 
 struct path *
-find_path_by_dev (const struct _vector *pathvec, const char *dev)
+find_path_by_dev (const struct vector_s *pathvec, const char *dev)
 {
 	int i;
 	struct path * pp;
@@ -513,7 +537,7 @@ find_path_by_dev (const struct _vector *pathvec, const char *dev)
 }
 
 struct path *
-find_path_by_devt (const struct _vector *pathvec, const char * dev_t)
+find_path_by_devt (const struct vector_s *pathvec, const char * dev_t)
 {
 	int i;
 	struct path * pp;
