@@ -59,7 +59,7 @@ struct client {
 	int fd;
 	vector cmdvec;
 	/* NUL byte at end */
-	char cmd[_MAX_CMD_LEN + 1];
+	char cmd[MAX_CMD_LEN + 1];
 	struct strbuf reply;
 	struct handler *handler;
 	size_t cmd_len, len;
@@ -392,6 +392,11 @@ static void drain_idle_fd(int fd)
 
 void default_reply(struct client *c, int r)
 {
+	if (r == 0) {
+		append_strbuf_str(&c->reply, "ok\n");
+		return;
+	}
+	append_strbuf_str(&c->reply, "fail\n");
 	switch(r) {
 	case -EINVAL:
 	case -ESRCH:
@@ -406,13 +411,11 @@ void default_reply(struct client *c, int r)
 	case -ETIMEDOUT:
 		append_strbuf_str(&c->reply, "timeout\n");
 		break;
-	case 0:
-		append_strbuf_str(&c->reply, "ok\n");
-		break;
-	default:
-		/* cli_handler functions return 1 on unspecified error */
-		append_strbuf_str(&c->reply, "fail\n");
+	case -EBUSY:
+		append_strbuf_str(&c->reply, "map or partition in use\n");
 		break;
+	case -ENODEV:
+		append_strbuf_str(&c->reply, "device not found\n");
 	}
 }
 
@@ -474,7 +477,7 @@ static int client_state_machine(struct client *c, struct vectors *vecs,
 				condlog(1, "%s: cli[%d]: failed to receive reply len: %zd",
 					__func__, c->fd, n);
 				c->error = -ECONNRESET;
-			} else if (len <= 0 || len > _MAX_CMD_LEN) {
+			} else if (len <= 0 || len > MAX_CMD_LEN) {
 				condlog(1, "%s: cli[%d]: invalid command length (%zu bytes)",
 					__func__, c->fd, len);
 				c->error = -ECONNRESET;
@@ -524,7 +527,7 @@ static int client_state_machine(struct client *c, struct vectors *vecs,
 	case CLT_LOCKED_WORK:
 		if (trylock(&vecs->lock) == 0) {
 			/* don't use cleanup_lock(), lest we wakeup ourselves */
-			pthread_cleanup_push_cast(__unlock, &vecs->lock);
+			pthread_cleanup_push_cast(unlock__, &vecs->lock);
 			c->error = execute_handler(c, vecs);
 			check_for_locked_work(c);
 			pthread_cleanup_pop(1);
